@@ -122,7 +122,7 @@ def test_line(ax, plotter):
     _process_event("__mouse_click__", ax, (.1, .4), 1)
     assert len(cursor.selections) == len(ax.figure.artists) == 1
     assert _parse_annotation(
-        cursor.selections[0], "foo\nx=(.*)\ny=(.*)") == approx((.1, .4))
+        cursor.selections[0], r"foo\nx=(.*)\ny=(.*)") == approx((.1, .4))
     # Not removing it.
     _process_event("__mouse_click__", ax, (0, 1), 3)
     assert len(cursor.selections) == len(ax.figure.artists) == 1
@@ -131,7 +131,7 @@ def test_line(ax, plotter):
     _process_event("__mouse_click__", ax, (.6, .9), 1)
     assert len(cursor.selections) == len(ax.figure.artists) == 2
     assert _parse_annotation(
-        cursor.selections[1], "x=(.*)\ny=(.*)") == approx((.6, .9))
+        cursor.selections[1], r"x=(.*)\ny=(.*)") == approx((.6, .9))
     # Remove both of them (first removing the second one, to test
     # `Selection.__eq__` -- otherwise it is bypassed as `list.remove`
     # checks identity first).
@@ -161,7 +161,7 @@ def test_scatter_text(ax):
     cursor = mplcursors.cursor()
     _process_event("__mouse_click__", ax, (0, 0), 1)
     assert _parse_annotation(
-        cursor.selections[0], "x=(.*)\ny=(.*)\n\[(.*)\]") == (0, 0, 2)
+        cursor.selections[0], r"x=(.*)\ny=(.*)\n\[(.*)\]") == (0, 0, 2)
 
 
 def test_steps_index():
@@ -365,7 +365,7 @@ def test_errorbar(ax):
     _process_event("__mouse_click__", ax, (.5, .5), 1)
     assert cursor.selections[0].target == approx((.5, .5))
     assert _parse_annotation(
-        cursor.selections[0], "x=(.*)\ny=(.*)") == approx((.5, .5))
+        cursor.selections[0], r"x=(.*)\ny=(.*)") == approx((.5, .5))
     _process_event("__mouse_click__", ax, (0, 1), 1)
     assert cursor.selections[0].target == approx((0, 0))
     assert _parse_annotation(
@@ -387,8 +387,11 @@ def test_dataless_errorbar(ax):
 
 
 def test_stem(ax):
-    with pytest.warns(None):  # stem use_line_collection API change.
-        ax.stem([1, 2, 3], use_line_collection=True)
+    try:  # stem use_line_collection API change.
+        with pytest.warns(None):
+            ax.stem([1, 2, 3], use_line_collection=True)
+    except TypeError:
+        ax.stem([1, 2, 3])
     cursor = mplcursors.cursor()
     assert len(cursor.artists) == 1
     _process_event("__mouse_click__", ax, (.5, .5), 1)
@@ -476,7 +479,8 @@ def test_hover(ax, hover):
 
 
 @pytest.mark.parametrize("plotter", [Axes.plot, Axes.scatter])
-def test_highlight(ax, plotter):
+@pytest.mark.parametrize("remove_click_on_annotation", [True, False])
+def test_highlight(ax, plotter, remove_click_on_annotation):
     plotter(ax, [0, 1], [0, 1])
     ax.set(xlim=(-1, 2), ylim=(-1, 2))
     base_children = {*ax.artists, *ax.lines, *ax.collections}
@@ -486,8 +490,12 @@ def test_highlight(ax, plotter):
     # to its type-specific container.  The construct below handles both cases.
     assert [*{*ax.artists, *ax.lines, *ax.collections} - base_children] \
         == cursor.selections[0].extras != []
-    _process_event(*_get_remove_args(cursor.selections[0]))
-    assert len({*ax.artists, *ax.lines, *ax.collections} - base_children) == 0
+    if remove_click_on_annotation:
+        _process_event(*_get_remove_args(cursor.selections[0]))
+    else:
+        _process_event("__mouse_click__", ax, (1, 1), 3)
+    assert len({*ax.artists, *ax.lines, *ax.collections} - base_children) == (
+        1 if plotter is Axes.scatter and not remove_click_on_annotation else 0)
 
 
 def test_misc_artists_highlight(ax):
